@@ -32,3 +32,6 @@ class UserSchema(Schema):
     email = fields.String()
     password = fields.String(load_only=True)
     active = fields.Integer()
+    registration_date = fields.DateTime()
+    activation_date = fields.DateTime()
+    updated_date = fields.DateTime()
